@@ -1,10 +1,10 @@
 ######################################################################
 ### Bell View
-### Copyright (c) 2020 Jonathan Wilson
+### Copyright (c) 2021 Jonathan Wilson
 ### Please refer to help/licence.txt for further information
 ### File: bvapp.py
 ### Description: Bell View GUI Application
-### Last Modified: 26 May 2020
+### Last Modified: 3 January 2021
 ######################################################################
 
 ### import modules
@@ -730,9 +730,9 @@ another application.'''
         'name': 'Bell View'
         , 'fullname': 'Bell View Ringing Engine'
         , 'author': 'Jonathan Wilson'
-        , 'year': '2020'
-        , 'version': '3.1.1'
-        , 'release': '26 May 2020'
+        , 'year': '2021'
+        , 'version': '3.2.1'
+        , 'release': '3 January 2021'
         , 'url': 'www.harrogatebellringers.org/bellview'
         }
 
